@@ -7,8 +7,8 @@
 ;; Maintainer: Caramel Hooves <caramel.hooves@protonmail.com>
 ;; Created: March 18, 2023
 ;; Modified: October 7, 2025
-;; Package-Version: 20251009.739
-;; Package-Revision: 0cda22331701
+;; Package-Version: 20251015.2150
+;; Package-Revision: 15e6148d0f8c
 ;; Keywords: tools
 ;; Homepage: https://github.com/caramelhooves/teleport.el
 ;; Package-Requires: ((emacs "28.1") (dash "2.18.0"))
@@ -217,7 +217,6 @@ EVENT is the event that caused the process to exit."
   (with-current-buffer (process-buffer process)
     (cond
      ((string= event "finished\n")
-      (delete-windows-on (current-buffer) 't)
       (kill-buffer))
      (t
       (message "Teleport stderr helper process failed: %s, %s"
@@ -255,16 +254,17 @@ terminates, call COMPLETION-NOTIFICATION."
 
 (defun teleport--tsh-cmd-async-cached (output-json-symbol process-symbol completion-notification cmd)
   "Start CMD asynchronously if PROCESS-SYMBOL process is not running.
-Store the result in OUTPUT-JSON-SYMBOL and call
-COMPLETION-NOTIFICATION when done."
+If the process is running, kill it and start again. Store the result in
+OUTPUT-JSON-SYMBOL and call COMPLETION-NOTIFICATION when done."
 
   (unless completion-notification
     (setq completion-notification
           (lambda () (message "Teleport cmd done: %s" cmd))))
 
   (let ((old-proc (symbol-value process-symbol)))
-    ;; If the process is *not* running, start the async command
-    (unless (process-live-p old-proc)
+    ;; If the process is running, kill it and try again
+    (if (process-live-p old-proc)
+        (kill-process old-proc))
       (teleport--tsh-cmd-async
              output-json-symbol
              process-symbol
@@ -280,7 +280,7 @@ COMPLETION-NOTIFICATION when done."
 
 (defun teleport--get-nodes-async-cached
     (&optional completion-notification)
-  "Return cached list of teleport nodes.
+  "Return a list of teleport nodes.
 Call COMPLETION-NOTIFICATION when a new list is available."
   (teleport--tsh-cmd-async-cached 'teleport--nodes-async-cache
                                   'teleport--nodes-async-process
@@ -504,8 +504,8 @@ If no nodes are tagged, return node at point"
            (save-excursion (goto-char (point-min))
                            (cl-loop
                             while (re-search-forward re nil 'noerror)
-                            collect (tabulated-list-get-id)))))
-      (or tagged-nodes (list (tabulated-list-get-id))))))
+                            collect (teleport-list--get-hostname)))))
+      (or tagged-nodes (list (teleport-list--get-hostname))))))
 
 (defun teleport-list-nodes-mode--copy-nodes-id ()
   "Copy the IDs of the tagged nodes to the kill ring.
@@ -616,10 +616,10 @@ Extract the values of the properties specified in LIST-FORMAT from NODES."
     (let ((pstatus (process-status process)))
       (propertize
        (cond
-        ((memq pstatus '(run open listen connect stop)) ":Nodes(Running)")
-        ((memq pstatus '(signal)) ":Nodes(Signal)")
-        ((and (memq pstatus '(exit)) (= 0 (process-exit-status process))) ":Nodes")
-        ((and (memq pstatus '(exit failed)) (/= 0 (process-exit-status process))) ":Nodes(Error)")
+        ((memq pstatus '(run open listen connect stop)) (format ":Running, PID %d" (process-id process)))
+        ((memq pstatus '(signal)) ":Signal")
+        ((and (memq pstatus '(exit)) (= 0 (process-exit-status process))) "")
+        ((and (memq pstatus '(exit failed)) (/= 0 (process-exit-status process))) ":Error")
         (t ":Nodes(Unknown State)" ))
        'mouse-face 'mode-line-highlight
        'help-echo (format "mouse-1: Open process error buffer")
